import React from "react";
import FieldSingleSetting from './FieldSingleSetting';
import MultipleFieldsModal from './MultipleFieldsModal';
import SingleFieldsModal from './SingleFieldsModal';
import type { ModalProps } from 'rlj-design';
export interface PropertyType {
    fieldName?: string;
    fieldId?: string;
    fieldDisabled?: boolean;
    checkable?: boolean;
    groupName?: string;
    groupId?: string;
    status?: 'normal' | 'remove';
}
export interface ColumnsItemType extends PropertyType {
    groupName?: string;
    groupId?: string;
    groupDisabled?: boolean;
    children?: PropertyType[];
    status?: 'normal' | 'remove';
}
export interface FieldSettingProps {
    /** 所有字段 */
    columns: ColumnsItemType[];
    /** 样式类名 */
    className?: string;
    /** 被选中的字段 */
    defaultSelectFields: ColumnsItemType[];
    /** 字段拖拽是否分组 */
    isMultipleDragGroup?: boolean;
    /** 字段拖拽容器宽度 */
    fieldDragWidth?: number;
    /** 保存时的回调 */
    onOk?: (selectFields: ColumnsItemType[]) => void;
    /** 左侧字段勾选组件属性 */
    fieldCheckboxProps?: Omit<FieldCheckboxProps, 'isCheckboxGroup'>;
    /** 右侧字段拖拽组件属性 */
    fieldDragProps?: Omit<FieldDragProps, 'isDragGroup'>;
    /** 监听selectFields值变化时的回调 */
    watchSelectFields?: (selectFields: ColumnsItemType[]) => void;
    /** css样式 */
    style?: React.CSSProperties;
    /** 字段是否可拖拽 */
    dragable?: boolean;
    /** 分组是否可拖拽 */
    groupDragable?: boolean;
}
export interface CompoundedComponent extends React.ForwardRefExoticComponent<FieldSettingProps & React.RefAttributes<any>> {
    FieldSingleSetting: typeof FieldSingleSetting;
    MultipleFieldsModal: typeof MultipleFieldsModal;
    SingleFieldsModal: typeof SingleFieldsModal;
}
export interface SinglePropertyType {
    fieldName: string;
    fieldId: string;
    fieldDisabled?: boolean;
    status?: 'normal' | 'remove';
}
export interface FieldSingleSettingProps {
    /** 所有字段 */
    columns: SinglePropertyType[];
    /** 样式类名 */
    className?: string;
    /** 被选中的字段 */
    defaultSelectFields: SinglePropertyType[];
    /** css样式 */
    style?: React.CSSProperties;
    /** 字段拖拽容器宽度 */
    fieldDragWidth?: number;
    /** 保存时的回调 */
    onOk?: (selectFields: ColumnsItemType[], selectFieldId: string[]) => void;
    /** 监听selectFields值变化时的回调 */
    watchSelectFields?: (selectFields: ColumnsItemType[]) => void;
    /** 左侧字段勾选组件属性 */
    fieldCheckboxProps?: Omit<FieldCheckboxProps, 'isCheckboxGroup'>;
    /** 右侧字段拖拽组件属性 */
    fieldDragProps?: Omit<FieldDragProps, 'isDragGroup'>;
    /** 字段是否可拖拽 */
    dragable?: boolean;
}
export interface FieldCheckboxProps {
    className?: string;
    isCheckboxGroup: boolean;
    header?: React.ReactNode;
    style?: React.CSSProperties;
}
export interface FieldDragProps {
    className?: string;
    isDragGroup: boolean;
    header?: React.ReactNode;
    style?: React.CSSProperties;
}
export interface MultipleFieldsModalProps extends FieldSettingProps {
    open?: boolean;
    title?: ModalProps['title'];
    loading?: boolean;
    okText?: ModalProps['okText'];
    cancelText?: ModalProps['cancelText'];
    onCancel?: ModalProps['onCancel'];
    modalProps?: ModalProps;
}
export interface SingleFieldsModalProps extends FieldSingleSettingProps {
    open?: boolean;
    title?: ModalProps['title'];
    loading?: boolean;
    okText?: ModalProps['okText'];
    cancelText?: ModalProps['cancelText'];
    onCancel?: ModalProps['onCancel'];
    modalProps?: ModalProps;
}
